@@ -57,7 +57,7 @@ def test_title(cipher_signature):
 
 
 def test_expiration(cipher_signature):
-    assert cipher_signature.streams[0].expiration == datetime(2020, 10, 30, 5, 39, 41)
+    assert cipher_signature.streams[0].expiration >= datetime(2020, 10, 30, 5, 39, 41)
 
 
 def test_caption_tracks(presigned_video):
@@ -97,7 +97,15 @@ def test_description(cipher_signature):
 
 
 def test_rating(cipher_signature):
-    assert cipher_signature.rating == 2.0860765
+    """Test the rating value of a YouTube object.
+
+    This changes each time we rebuild the json files, so we want to use
+    an estimate of where it will be. The two values seen to make this
+    estimate were 2.073431 and 2.0860765. This represents a range of
+    ~0.007 below and ~0.006 above 2.08. Allowing for up to 0.02 in either
+    direction should provide a steady indicator of correctness.
+    """
+    assert abs(cipher_signature.rating - 2.08) < 0.02
 
 
 def test_length(cipher_signature):
